@@ -213,13 +213,13 @@ sub start {
 }
 
 1;
-
 __END__
 
-
 =head1 SEE ALSO
 
-L<http://perlcabal.org/syn/S26.html>
+L<http://zag.ru/perl6-pod/S26.html>,
+Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
+Perl6::Pod::Lib
 
 =head1 AUTHOR
 
@@ -233,6 +233,5 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
 
