@@ -32,7 +32,7 @@ Exported :
 
 =over 
 
-=item *  docbook 
+=item *  doc book 
 
     <code></code>
 
@@ -52,6 +52,22 @@ use base 'Perl6::Pod::FormattingCode';
 use strict;
 use warnings;
 
+sub on_para {
+    my ($self, $p ,$t )= @_;
+    $t;
+#    return $self->htnml_escape($t);
+}
+
+sub htnml_escape {
+    my ($self, $txt ) =@_;
+    $txt   =~ s/&/&amp;/g;
+    $txt   =~ s/</&lt;/g;
+    $txt   =~ s/>/&gt;/g;
+    $txt   =~ s/"/&quot;/g;
+    $txt   =~ s/'/&apos;/g;
+    $txt
+}
+
 sub to_xhtml {
     my $self   = shift;
     my $parser = shift;
